/* ===============
 * JFreeChart Demo
 * ===============
 *
 * Project Info:  http://www.object-refinery.com/jfreechart/index.html
 * Project Lead:  David Gilbert (david.gilbert@object-refinery.com);
 *
 * (C) Copyright 2000-2002, by Simba Management Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * -------------------
 * LineChartDemo1.java
 * -------------------
 * (C) Copyright 2002, by Hari and Contributors.
 *
 * Original Author:  Hari;
 * Contributor(s):   -;
 *
 * $Id: MeterPlotDemo.java,v 1.7 2002/06/26 16:53:56 mungady Exp $
 *
 * Changes
 * -------
 * 08-Apr-2002 : Version 1, contributed by Hari (DG);
 * 19-Apr-2002 : Renamed JRefineryUtilities-->RefineryUtilities (DG);
 * 25-Jun-2002 : Removed unnecessary imports (DG);
 *
 */

package com.jrefinery.chart.demo;

import com.jrefinery.chart.JFreeChart;
import com.jrefinery.chart.ChartFrame;
import com.jrefinery.chart.MeterPlot;
import com.jrefinery.chart.MeterLegend;
import com.jrefinery.data.MeterDataset;
import com.jrefinery.data.DefaultMeterDataset;
import com.jrefinery.ui.RefineryUtilities;
import java.awt.Insets;
import java.awt.Color;
import java.awt.GradientPaint;
import javax.swing.JFrame;

/**
 * The main frame in the chart demonstration application.
 */
public class MeterPlotDemo {

    void displayMeterChart(double value, int type) {

        JFreeChart chart = null;

        String title = "Meter Chart";
        DefaultMeterDataset data = new DefaultMeterDataset(new Double(23), new Double(140),
                                                           new Double(value), "Units");
        data.setNormalRange(new Double(70), new Double(85));
        data.setWarningRange(new Double(85), new Double(100));
        data.setCriticalRange(new Double(50), new Double(120));
        data.setBorderType(MeterDataset.CRITICAL_DATA);

        MeterPlot plot = new MeterPlot(data);
        plot.setMeterAngle(270);
        plot.setDialType(type);

        plot.setInsets(new Insets(5, 5, 5, 5));
        chart = new JFreeChart(title, JFreeChart.DEFAULT_TITLE_FONT, plot, false);

        MeterLegend legend = new MeterLegend( chart, "Sample Meter");
        chart.setLegend( legend);

        chart.setBackgroundPaint(new GradientPaint(0, 0, Color.white, 0, 1000, Color.blue));

        JFrame chartFrame = new ChartFrame("Meter Chart", chart);
        chartFrame.pack();
        RefineryUtilities.positionFrameRandomly(chartFrame);
        chartFrame.setSize(250, 250);
        chartFrame.show();

   }

    /**
     * Starting point for the Meter Plot demonstration application.
     */
    public static void main(String[] args) {

        if( args.length == 0) {
                System.err.println( "Usage: java TestMeter <type> <value>");
                System.err.println( "Type:  0 = DIALTYPE_PIE");
                System.err.println( "Type:  1 = DIALTYPE_CIRCLE");
                System.err.println( "Type:  2 = DIALTYPE_CHORD");
        }

        MeterPlotDemo h = new MeterPlotDemo();
        double val = 50;
        int type = MeterPlot.DIALTYPE_CIRCLE;
        if (args.length>0) {
            type = Integer.parseInt(args[0]);
        }
        if (args.length>1) {
            val = new Double(args[1]).doubleValue();
        }
        h.displayMeterChart(val, type);

    }

}
